Compiling with CMake


Compiling
1. Create a directory named "build" inside the root directory.
2. Navigate into the directory.
3. Run `cmake ..`
4. Run `cmake --build . --config Release`


The epanetmsx.dll will be built in the bin/Release directory.

